@@ -23,7 +23,7 @@ namespace igl
   /// @param[out] Y  m by n matrix of rounded integers
   template < typename DerivedX, typename DerivedY>
   IGL_INLINE void round(
-    const Eigen::PlainObjectBase<DerivedX>& X,
+    const Eigen::MatrixBase<DerivedX>& X,
     Eigen::PlainObjectBase<DerivedY>& Y);
 }
 
